from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.ml_model_status import MLModelStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="MLModel")


@_attrs_define
class MLModel:
    """
    Attributes:
        name (str):
        url (str):
        requests_count (int):
        cost (str):
        status (MLModelStatus):
        id (Union[Unset, str]):
    """

    name: str
    url: str
    requests_count: int
    cost: str
    status: MLModelStatus
    id: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        url = self.url

        requests_count = self.requests_count

        cost = self.cost

        status = self.status.value

        id = self.id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "url": url,
                "requests_count": requests_count,
                "cost": cost,
                "status": status,
            }
        )
        if id is not UNSET:
            field_dict["id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        url = d.pop("url")

        requests_count = d.pop("requests_count")

        cost = d.pop("cost")

        status = MLModelStatus(d.pop("status"))

        id = d.pop("id", UNSET)

        ml_model = cls(
            name=name,
            url=url,
            requests_count=requests_count,
            cost=cost,
            status=status,
            id=id,
        )

        ml_model.additional_properties = d
        return ml_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
